cmoncrawl.processor.pipeline.streamer
=====================================

.. automodule:: cmoncrawl.processor.pipeline.streamer

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: BaseStreamerFile
      :members:

   .. autoclass:: IStreamer
      :members:

   .. autoclass:: MemoryStreamer
      :members:

   .. autoclass:: StreamerFileHTML
      :members:

   .. autoclass:: StreamerFileJSON
      :members:

   
   
   



